For those who are struggling with Rust’s cool syntax, our goal is to provide a TOML parser that’s as easy as pointing to a menu and eating fast food.
Rustのイケてる構文に難儀している人のために、メニューを指差してファーストフードを食べるぐらい簡単な操作のTOMLパーサーを提供することを目標とします。
Modules
Structs
- Toml
- TOML.
トムル。